@@ -36,7 +36,7 @@ class BaseHandler(tornado.web.RequestHandler):
         self.scheme = self.request.headers.get('Scheme', self.request.protocol)
 
     def _request_summary(self):
-        return f"{self.request.method} {self.request.uri} ({self.referer})"
+        return f"{self.request.method} {self.request.uri} ({self.ip}) ({self.referer})"
 
     def __getattr__(self, key):
         value = getattr(self.app, key)
@@ -126,7 +126,7 @@ class BaseHandler(tornado.web.RequestHandler):
         return super().write(chunk)
 
     def write_error(self, status_code, **kwargs):
-        if self.application.settings.get('debug') and kwargs.get('exc_info'):
+        if kwargs.get('exc_info'):
             msg = ''.join(traceback.format_exception(*kwargs["exc_info"]))
             self.logger.error(msg)
         super().write_error(status_code, **kwargs)
