@@ -616,7 +616,7 @@ class Pycurl(BaseRequest):
         curl.setopt(pycurl.SSL_VERIFYHOST, 0)
         # curl.setopt(pycurl.AUTOREFERER, 1)
         # 导致未知的403错误 https://video.wanmeikk.me/hls/a02689e5-d0f6-4a55-a590-75119b142a21/d6MJXL_kK9bOc1cTqAs3vVOWDA6wepIKOln9hG_oIT2vMXt81bvAsSaNmOVnaXAcM2BsEd87CSN9VlFIrLZuSw==.ts
-        curl.setopt(pycurl.URL, native_str(url))
+        curl.setopt(pycurl.URL, urllib.parse.quote(url, safe='#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~'))
 
         curl.setopt(pycurl.TRANSFER_ENCODING, int(kwargs.get('chunked', False)))
         curl.setopt(pycurl.FOLLOWLOCATION, kwargs['allow_redirects'])
@@ -891,6 +891,7 @@ class Chrome(webdriver.Chrome):
     def __init__(self, path=None, headless=False, proxy=None, mobile=False):
         options = webdriver.ChromeOptions()
         options.add_experimental_option("excludeSwitches", ["ignore-certificate-errors"])
+        options.add_experimental_option('w3c', False)
         options.add_argument('disable-infobars')
         options.add_argument('lang=zh_CN.UTF-8')
         options.add_argument('profile-directory=Default')
@@ -908,9 +909,9 @@ class Chrome(webdriver.Chrome):
             options.add_argument('user-agent="Mozilla/5.0 (iPhone; CPU iPhone OS 9_1 like Mac OS X) AppleWebKit/601.1.46 (KHTML, like Gecko) Version/9.0 Mobile/13B143 Safari/601.1"')
         elif mobile == 'android':
             options.add_argument('user-agent="Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.87 Mobile Safari/537.36"')
-        d = DesiredCapabilities.CHROME
-        d['loggingPrefs'] = {'performance': 'ALL'}
-        super().__init__(chrome_options=options, desired_capabilities=d)
+        caps = DesiredCapabilities.CHROME
+        caps['loggingPrefs'] = {'performance': 'ALL'}
+        super().__init__(options=options, desired_capabilities=caps)
         self.wait = WebDriverWait(self, 30)
 
     def get(self, url):
@@ -919,7 +920,7 @@ class Chrome(webdriver.Chrome):
         resp = Dict()
         for item in self.get_log('performance'):
             message = Dict(json.loads(item['message'])).message
-            if message['method'] == 'Network.responseReceived' and \
+            if message.method == 'Network.responseReceived' and \
                     message.params.response.url.strip('/') == url.strip('/'):
                 resp.headers = CaseInsensitiveDict(message.params.response.headers)
                 request.headers = CaseInsensitiveDict(message.params.response.requestHeaders)
